@@ -7,7 +7,8 @@ from . import types
 
 ENDPOINT_TRANSCRIPT = "/v2/transcript"
 ENDPOINT_UPLOAD = "/v2/upload"
-ENDPOINT_LEMUR = "/lemur/v3/generate"
+ENDPOINT_LEMUR_BASE = "/lemur/v3"
+ENDPOINT_LEMUR = f"{ENDPOINT_LEMUR_BASE}/generate"
 
 
 def _get_error_message(response: httpx.Response) -> str:
@@ -270,6 +271,27 @@ def lemur_summarize(
     return types.LemurSummaryResponse.parse_obj(response.json())
 
 
+def lemur_action_items(
+    client: httpx.Client,
+    request: types.LemurActionItemsRequest,
+    http_timeout: Optional[float],
+) -> types.LemurActionItemsResponse:
+    response = client.post(
+        f"{ENDPOINT_LEMUR}/action-items",
+        json=request.dict(
+            exclude_none=True,
+        ),
+        timeout=http_timeout,
+    )
+
+    if response.status_code != httpx.codes.ok:
+        raise types.LemurError(
+            f"failed to call Lemur action items: {_get_error_message(response)}"
+        )
+
+    return types.LemurActionItemsResponse.parse_obj(response.json())
+
+
 def lemur_task(
     client: httpx.Client,
     request: types.LemurTaskRequest,
@@ -289,3 +311,21 @@ def lemur_task(
         )
 
     return types.LemurTaskResponse.parse_obj(response.json())
+
+
+def lemur_purge_request_data(
+    client: httpx.Client,
+    request: types.LemurPurgeRequest,
+    http_timeout: Optional[float],
+) -> types.LemurPurgeRequest:
+    response = client.delete(
+        f"{ENDPOINT_LEMUR_BASE}/{request.request_id}",
+        timeout=http_timeout,
+    )
+
+    if response.status_code != httpx.codes.ok:
+        raise types.LemurError(
+            f"Failed to purge LeMUR request data for provided request ID: {request.request_id}. Error: {_get_error_message(response)}"
+        )
+
+    return types.LemurPurgeResponse.parse_obj(response.json())
