@@ -252,6 +252,15 @@ class EntityType(str, Enum):
     banking_information = "banking_information"
     "Banking information, including account and routing numbers"
 
+    time = "time"
+    "Expressions indicating clock times (e.g., 19:37:28, 10pm EST)"
+
+    url = "url"
+    "Internet addresses (e.g., www.assemblyai.com)"
+
+    password = "password"
+    "Account passwords, PINs, access keys, or verification answers (e.g., 27%alfalfa, temp1234, My mother's maiden name is Smith)"
+
 
 # EntityType and PIIRedactionPolicy share the same values
 PIIRedactionPolicy = EntityType
@@ -826,7 +835,7 @@ class TranscriptionConfig:
         "Enable Auto Chapters."
 
         # Validate required params are also set
-        if enable and self.punctuate == False:
+        if enable and self.punctuate is False:
             raise ValueError(
                 "If `auto_chapters` is enabled, then `punctuate` must not be disabled"
             )
@@ -1137,11 +1146,11 @@ class TranscriptionConfig:
             return self
 
         # Validate that required parameters are also set
-        if self._raw_transcription_config.punctuate == False:
+        if self._raw_transcription_config.punctuate is False:
             raise ValueError(
                 "If `summarization` is enabled, then `punctuate` must not be disabled"
             )
-        if self._raw_transcription_config.format_text == False:
+        if self._raw_transcription_config.format_text is False:
             raise ValueError(
                 "If `summarization` is enabled, then `format_text` must not be disabled"
             )
@@ -1238,6 +1247,7 @@ class Word(BaseModel):
     start: int
     end: int
     confidence: float
+    speaker: Optional[str]
 
 
 class UtteranceWord(Word):
@@ -1373,6 +1383,10 @@ class RedactedAudioResponse(BaseModel):
 
 class Sentence(Word):
     words: List[Word]
+    start: int
+    end: int
+    confidence: int
+    speaker: Optional[str]
 
 
 class SentencesResponse(BaseModel):
@@ -1383,6 +1397,10 @@ class SentencesResponse(BaseModel):
 
 class Paragraph(Word):
     words: List[Word]
+    start: int
+    end: int
+    confidence: int
+    text: str
 
 
 class ParagraphsResponse(BaseModel):
@@ -1657,7 +1675,7 @@ class LemurTranscriptSource(LemurSource):
         """
         from . import Transcript
 
-        if type(transcript) == str:
+        if isinstance(transcript, str):
             transcript = Transcript(transcript_id=transcript)
 
         super().__init__(transcript)
@@ -1686,10 +1704,10 @@ class LemurSourceRequest(BaseModel):
 
 class LemurModel(str, Enum):
     """
-    LeMUR features two model modes, Basic and Default, that allow you to configure your request
-    to suit your needs. These options tell LeMUR whether to use the more advanced Default model or
-    the cheaper, faster, but simplified Basic model. The implicit setting is Default when no option
-    is explicitly passed in.
+    LeMUR features four model modes, Basic, Default, Mistral 7B, and Claude v2.1, that allow you to
+    configure your request to suit your needs. These options tell LeMUR whether to use the more
+    advanced Default model or the cheaper, faster, but simplified Basic model. The implicit setting
+    is Default when no option is explicitly passed in.
     """
 
     default = "default"
@@ -1711,6 +1729,13 @@ class LemurModel(str, Enum):
     for complex/subjective tasks where answers require more nuance to be effective.
     """
 
+    mistral7b = "assemblyai/mistral-7b"
+    """
+    Mistral 7B is an open source model that works well for summarization and answering questions.
+    """
+
+    claude2_1 = "anthropic/claude-2-1"
+
 
 class LemurQuestionAnswer(BaseModel):
     """
@@ -1764,6 +1789,7 @@ class BaseLemurRequest(BaseModel):
     final_model: Optional[LemurModel]
     max_output_size: Optional[int]
     temperature: Optional[float]
+    input_text: Optional[str]
 
 
 class LemurTaskRequest(BaseLemurRequest):
@@ -1856,6 +1882,7 @@ class RealtimeMessageTypes(str, Enum):
     partial_transcript = "PartialTranscript"
     final_transcript = "FinalTranscript"
     session_begins = "SessionBegins"
+    session_terminated = "SessionTerminated"
 
 
 class RealtimeSessionOpened(BaseModel):
@@ -1910,7 +1937,7 @@ class RealtimeTranscript(BaseModel):
     text: str
     "The transcript for your audio"
 
-    words: List[Word]
+    words: List[RealtimeWord]
     """
     An array of objects, with the information for each word in the transcription text.
     Will include the `start`/`end` time (in milliseconds) of the word, the `confidence` score of the word,
