@@ -177,6 +177,14 @@ class LemurSummaryResponse(factory.Factory):
     response = factory.Faker("text")
 
 
+class LemurActionItemsResponse(factory.Factory):
+    class Meta:
+        model = types.LemurActionItemsResponse
+
+    request_id = factory.Faker("uuid4")
+    response = factory.Faker("text")
+
+
 class LemurTaskResponse(factory.Factory):
     class Meta:
         model = types.LemurTaskResponse
@@ -185,6 +193,15 @@ class LemurTaskResponse(factory.Factory):
     response = factory.Faker("text")
 
 
+class LemurPurgeResponse(factory.Factory):
+    class Meta:
+        model = types.LemurPurgeResponse
+
+    request_id = factory.Faker("uuid4")
+    request_id_to_purge = factory.Faker("uuid4")
+    deleted = True
+
+
 class WordSearchMatchFactory(factory.Factory):
     class Meta:
         model = types.WordSearchMatch
